@@ -14,5 +14,7 @@
 // You should have received a copy of the GNU General Public License
 // along with cargo-contract.  If not, see <http://www.gnu.org/licenses/>.
 
-#[subxt::subxt(runtime_metadata_path = "src/cmd/extrinsics/runtime_api/contracts_runtime.scale")]
+#[subxt::subxt(
+    runtime_metadata_path = "src/cmd/extrinsics/runtime_api/contracts_runtime.scale"
+)]
 pub mod api {}
