@@ -16,14 +16,34 @@
 
 use super::{
     env_types::EnvTypesTranscoder,
-    scon::{Map, Tuple, Value},
+    scon::{
+        Map,
+        Tuple,
+        Value,
+    },
     CompositeTypeFields,
 };
-use anyhow::{Context, Result};
-use scale::{Compact, Decode, Input};
+use anyhow::{
+    Context,
+    Result,
+};
+use scale::{
+    Compact,
+    Decode,
+    Input,
+};
 use scale_info::{
-    form::{Form, PortableForm},
-    Field, PortableRegistry, Type, TypeDef, TypeDefCompact, TypeDefPrimitive, TypeDefVariant,
+    form::{
+        Form,
+        PortableForm,
+    },
+    Field,
+    PortableRegistry,
+    Type,
+    TypeDef,
+    TypeDefCompact,
+    TypeDefPrimitive,
+    TypeDefVariant,
 };
 
 pub struct Decoder<'a> {
@@ -32,7 +52,10 @@ pub struct Decoder<'a> {
 }
 
 impl<'a> Decoder<'a> {
-    pub fn new(registry: &'a PortableRegistry, env_types: &'a EnvTypesTranscoder) -> Self {
+    pub fn new(
+        registry: &'a PortableRegistry,
+        env_types: &'a EnvTypesTranscoder,
+    ) -> Self {
         Self {
             registry,
             env_types,
@@ -40,10 +63,9 @@ impl<'a> Decoder<'a> {
     }
 
     pub fn decode(&self, type_id: u32, input: &mut &[u8]) -> Result<Value> {
-        let ty = self
-            .registry
-            .resolve(type_id)
-            .ok_or_else(|| anyhow::anyhow!("Failed to resolve type with id `{:?}`", type_id))?;
+        let ty = self.registry.resolve(type_id).ok_or_else(|| {
+            anyhow::anyhow!("Failed to resolve type with id `{:?}`", type_id)
+        })?;
         log::debug!(
             "Decoding input with type id `{:?}` and definition `{:?}`",
             type_id,
@@ -65,10 +87,9 @@ impl<'a> Decoder<'a> {
         input: &mut &[u8],
     ) -> Result<Value> {
         let type_id = ty.id();
-        let ty = self
-            .registry
-            .resolve(type_id)
-            .ok_or_else(|| anyhow::anyhow!("Failed to find type with id '{}'", type_id))?;
+        let ty = self.registry.resolve(type_id).ok_or_else(|| {
+            anyhow::anyhow!("Failed to find type with id '{}'", type_id)
+        })?;
 
         if *ty.type_def() == TypeDef::Primitive(TypeDefPrimitive::U8) {
             let mut bytes = vec![0u8; len];
@@ -84,7 +105,12 @@ impl<'a> Decoder<'a> {
         }
     }
 
-    fn decode_type(&self, id: u32, ty: &Type<PortableForm>, input: &mut &[u8]) -> Result<Value> {
+    fn decode_type(
+        &self,
+        id: u32,
+        ty: &Type<PortableForm>,
+        input: &mut &[u8],
+    ) -> Result<Value> {
         match ty.type_def() {
             TypeDef::Composite(composite) => {
                 let ident = ty.path().segments().last().map(|s| s.as_str());
@@ -111,7 +137,9 @@ impl<'a> Decoder<'a> {
             }
             TypeDef::Primitive(primitive) => self.decode_primitive(primitive, input),
             TypeDef::Compact(compact) => self.decode_compact(compact, input),
-            TypeDef::BitSequence(_) => Err(anyhow::anyhow!("bitvec decoding not yet supported")),
+            TypeDef::BitSequence(_) => {
+                Err(anyhow::anyhow!("bitvec decoding not yet supported"))
+            }
         }
         .context(format!("Error decoding type {}: {}", id, ty.path()))
     }
@@ -144,7 +172,9 @@ impl<'a> Decoder<'a> {
                     tuple.into_iter().collect::<Vec<_>>(),
                 )))
             }
-            CompositeTypeFields::NoFields => Ok(Value::Tuple(Tuple::new(ident, Vec::new()))),
+            CompositeTypeFields::NoFields => {
+                Ok(Value::Tuple(Tuple::new(ident, Vec::new())))
+            }
         }
     }
 
@@ -185,23 +215,33 @@ impl<'a> Decoder<'a> {
         }
     }
 
-    fn decode_primitive(&self, primitive: &TypeDefPrimitive, input: &mut &[u8]) -> Result<Value> {
+    fn decode_primitive(
+        &self,
+        primitive: &TypeDefPrimitive,
+        input: &mut &[u8],
+    ) -> Result<Value> {
         match primitive {
             TypeDefPrimitive::Bool => Ok(Value::Bool(bool::decode(input)?)),
-            TypeDefPrimitive::Char => Err(anyhow::anyhow!("scale codec not implemented for char")),
+            TypeDefPrimitive::Char => {
+                Err(anyhow::anyhow!("scale codec not implemented for char"))
+            }
             TypeDefPrimitive::Str => Ok(Value::String(String::decode(input)?)),
             TypeDefPrimitive::U8 => decode_uint::<u8>(input),
             TypeDefPrimitive::U16 => decode_uint::<u16>(input),
             TypeDefPrimitive::U32 => decode_uint::<u32>(input),
             TypeDefPrimitive::U64 => decode_uint::<u64>(input),
             TypeDefPrimitive::U128 => decode_uint::<u128>(input),
-            TypeDefPrimitive::U256 => Err(anyhow::anyhow!("U256 currently not supported")),
+            TypeDefPrimitive::U256 => {
+                Err(anyhow::anyhow!("U256 currently not supported"))
+            }
             TypeDefPrimitive::I8 => decode_int::<i8>(input),
             TypeDefPrimitive::I16 => decode_int::<i16>(input),
             TypeDefPrimitive::I32 => decode_int::<i32>(input),
             TypeDefPrimitive::I64 => decode_int::<i64>(input),
             TypeDefPrimitive::I128 => decode_int::<i128>(input),
-            TypeDefPrimitive::I256 => Err(anyhow::anyhow!("I256 currently not supported")),
+            TypeDefPrimitive::I256 => {
+                Err(anyhow::anyhow!("I256 currently not supported"))
+            }
         }
     }
 
@@ -210,55 +250,87 @@ impl<'a> Decoder<'a> {
         compact: &TypeDefCompact<PortableForm>,
         input: &mut &[u8],
     ) -> Result<Value> {
-        let mut decode_compact_primitive = |primitive: &TypeDefPrimitive| match primitive {
-            TypeDefPrimitive::U8 => Ok(Value::UInt(Compact::<u8>::decode(input)?.0.into())),
-            TypeDefPrimitive::U16 => Ok(Value::UInt(Compact::<u16>::decode(input)?.0.into())),
-            TypeDefPrimitive::U32 => Ok(Value::UInt(Compact::<u32>::decode(input)?.0.into())),
-            TypeDefPrimitive::U64 => Ok(Value::UInt(Compact::<u64>::decode(input)?.0.into())),
-            TypeDefPrimitive::U128 => Ok(Value::UInt(Compact::<u128>::decode(input)?.into())),
-            prim => Err(anyhow::anyhow!(
-                "{:?} not supported. Expected unsigned int primitive.",
-                prim
-            )),
+        let mut decode_compact_primitive = |primitive: &TypeDefPrimitive| {
+            match primitive {
+                TypeDefPrimitive::U8 => {
+                    Ok(Value::UInt(Compact::<u8>::decode(input)?.0.into()))
+                }
+                TypeDefPrimitive::U16 => {
+                    Ok(Value::UInt(Compact::<u16>::decode(input)?.0.into()))
+                }
+                TypeDefPrimitive::U32 => {
+                    Ok(Value::UInt(Compact::<u32>::decode(input)?.0.into()))
+                }
+                TypeDefPrimitive::U64 => {
+                    Ok(Value::UInt(Compact::<u64>::decode(input)?.0.into()))
+                }
+                TypeDefPrimitive::U128 => {
+                    Ok(Value::UInt(Compact::<u128>::decode(input)?.into()))
+                }
+                prim => {
+                    Err(anyhow::anyhow!(
+                        "{:?} not supported. Expected unsigned int primitive.",
+                        prim
+                    ))
+                }
+            }
         };
 
         let type_id = compact.type_param().id();
-        let ty = self
-            .registry
-            .resolve(type_id)
-            .ok_or_else(|| anyhow::anyhow!("Failed to resolve type with id `{:?}`", type_id))?;
+        let ty = self.registry.resolve(type_id).ok_or_else(|| {
+            anyhow::anyhow!("Failed to resolve type with id `{:?}`", type_id)
+        })?;
         match ty.type_def() {
             TypeDef::Primitive(primitive) => decode_compact_primitive(primitive),
-            TypeDef::Composite(composite) => match composite.fields() {
-                [field] => {
-                    let type_id = field.ty().id();
-                    let field_ty = self.registry.resolve(type_id).ok_or_else(|| {
-                        anyhow::anyhow!("Failed to resolve type with id `{:?}`", type_id)
-                    })?;
-                    if let TypeDef::Primitive(primitive) = field_ty.type_def() {
-                        let struct_ident = ty.path().segments().last().map(|s| s.as_str());
-                        let field_value = decode_compact_primitive(primitive)?;
-                        let compact_composite = match field.name() {
-                            Some(name) => Value::Map(Map::new(
-                                struct_ident,
-                                vec![(Value::String(name.to_string()), field_value)]
-                                    .into_iter()
-                                    .collect(),
-                            )),
-                            None => Value::Tuple(Tuple::new(struct_ident, vec![field_value])),
-                        };
-                        Ok(compact_composite)
-                    } else {
-                        Err(anyhow::anyhow!(
-                            "Composite type must have a single primitive field"
-                        ))
+            TypeDef::Composite(composite) => {
+                match composite.fields() {
+                    [field] => {
+                        let type_id = field.ty().id();
+                        let field_ty =
+                            self.registry.resolve(type_id).ok_or_else(|| {
+                                anyhow::anyhow!(
+                                    "Failed to resolve type with id `{:?}`",
+                                    type_id
+                                )
+                            })?;
+                        if let TypeDef::Primitive(primitive) = field_ty.type_def() {
+                            let struct_ident =
+                                ty.path().segments().last().map(|s| s.as_str());
+                            let field_value = decode_compact_primitive(primitive)?;
+                            let compact_composite = match field.name() {
+                                Some(name) => {
+                                    Value::Map(Map::new(
+                                        struct_ident,
+                                        vec![(
+                                            Value::String(name.to_string()),
+                                            field_value,
+                                        )]
+                                        .into_iter()
+                                        .collect(),
+                                    ))
+                                }
+                                None => {
+                                    Value::Tuple(Tuple::new(
+                                        struct_ident,
+                                        vec![field_value],
+                                    ))
+                                }
+                            };
+                            Ok(compact_composite)
+                        } else {
+                            Err(anyhow::anyhow!(
+                                "Composite type must have a single primitive field"
+                            ))
+                        }
                     }
+                    _ => Err(anyhow::anyhow!("Composite type must have a single field")),
                 }
-                _ => Err(anyhow::anyhow!("Composite type must have a single field")),
-            },
-            _ => Err(anyhow::anyhow!(
-                "Compact type must be a primitive or a composite type"
-            )),
+            }
+            _ => {
+                Err(anyhow::anyhow!(
+                    "Compact type must be a primitive or a composite type"
+                ))
+            }
         }
     }
 }
