@@ -15,14 +15,23 @@
 // along with cargo-contract.  If not, see <http://www.gnu.org/licenses/>.
 
 pub mod build;
+pub mod decode;
 pub mod metadata;
 pub mod new;
 pub mod test;
 
 pub(crate) use self::{
-    build::{BuildCommand, CheckCommand},
+    build::{
+        BuildCommand,
+        CheckCommand,
+    },
+    decode::DecodeCommand,
     test::TestCommand,
 };
 mod extrinsics;
 
-pub(crate) use self::extrinsics::{CallCommand, InstantiateCommand, UploadCommand};
+pub(crate) use self::extrinsics::{
+    CallCommand,
+    InstantiateCommand,
+    UploadCommand,
+};
